## 管理层薪酬和持股

接口：stk_rewards

描述：获取上市公司管理层薪酬和持股

积分：用户需要2000积分才可以调取，5000积分以上频次相对较高，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS股票代码，支持单个或多个代码输入 |
| end_date | str | N | 报告期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS股票代码 |
| ann_date | str | Y | 公告日期 |
| end_date | str | Y | 截止日期 |
| name | str | Y | 姓名 |
| title | str | Y | 职务 |
| reward | float | Y | 报酬 |
| hold_vol | float | Y | 持股数 |

接口用例

```python
pro = ts.pro_api()

#获取单个公司高管全部数据
df = pro.stk_rewards(ts_code='000001.SZ')

#获取多个公司高管全部数据
df = pro.stk_rewards(ts_code='000001.SZ,600000.SH')
```

数据样例

```python
ts_code    ann_date  end_date      name     title     reward  hold_vol
0    000001.SZ  20190808  20190630  谢永林       董事长        NaN       0.0
```